@@ -2,10 +2,16 @@
 #'
 #' Posterior predictive probabilities for a football season in a round-robin format
 #'
-#' @param object An object of class \code{\link[rstan]{stanfit}} as given by \code{stan_foot} function.
-#' @param data A data frame, or a matrix containing the following mandatory items: home team, away team,
-#'home goals, away goals.
-#' @param team_sel Selected team(s). By default, all the teams are selected.
+#' @param object An object of class \code{\link[rstan]{stanfit}} or \code{stanFoot} as given by \code{stan_foot} function.
+#' @param data A data frame containing match data with columns:
+#'   \itemize{
+#'     \item \code{periods}:  Time point of each observation (integer >= 1).
+#'     \item \code{home_team}: Home team's name (character string).
+#'     \item \code{away_team}: Away team's name (character string).
+#'     \item \code{home_goals}: Goals scored by the home team (integer >= 0).
+#'     \item \code{away_goals}: Goals scored by the away team (integer >= 0).
+#'   }
+#' @param teams An optional character vector specifying team names to include. If \code{NULL}, all teams are included.
 #'
 #'@details
 #'
@@ -23,34 +29,54 @@
 #'@examples
 #'
 #'\dontrun{
-#'require(dplyr)
+#'library(dplyr)
 #'
 #'data("italy")
 #'italy_1999_2000<- italy %>%
 #' dplyr::select(Season, home, visitor, hgoal,vgoal) %>%
 #' dplyr::filter(Season == "1999"|Season=="2000")
 #'
+#'colnames(italy_1999_2000) <- c("periods", "home_team", "away_team", "home_goals", "away_goals")
+#'
 #'fit <- stan_foot(italy_1999_2000, "double_pois", predict = 45, iter = 200)
 #'
-#'foot_round_robin(italy_1999_2000, fit)
-#'foot_round_robin(italy_1999_2000, fit, c("Parma AC", "AS Roma"))
+#'foot_round_robin(fit, italy_1999_2000)
+#'foot_round_robin(fit, italy_1999_2000, c("Parma AC", "AS Roma"))
 #'
 #'}
-#'
-#'@importFrom dplyr as_tibble
+#' @import ggplot2
+#' @importFrom dplyr as_tibble
 #' @export
 
 
-foot_round_robin <- function(data, object, team_sel){
-  # # plot for the torunament "box"
-  colnames(data) <- c("season", "home", "away",
-                      "homegoals", "awaygoals")
+foot_round_robin <- function(object, data, teams = NULL){
 
-  sims <- rstan::extract(object)
+  if (!requireNamespace("ggplot2", quietly = TRUE)) {
+    stop("Package 'ggplot2' is required for plotting.")
+  }
+
+  required_cols <- c("periods", "home_team", "away_team", "home_goals", "away_goals")
+  missing_cols <- setdiff(required_cols, names(data))
+  if (length(missing_cols) > 0) {
+    stop(paste("data is missing required columns:", paste(missing_cols, collapse = ", ")))
+  }
+  # # plot for the torunament "box"
+  # colnames(data) <- c("season", "home", "away",
+  #                     "homegoals", "awaygoals")
+
+  if (inherits(object, "stanFoot")) {
+    stan_fit <- object$fit
+  } else if (inherits(object, "stanfit")) {
+    stan_fit <- object
+  } else {
+    stop("Please provide an object of class 'stanfit' or 'stanFoot'.")
+  }
+
+  sims <- rstan::extract(stan_fit)
   y <- as.matrix(data[,4:5])
-  teams <- unique(data$home)
-  team_home <- match(data$home, teams)
-  team_away <- match(data$away, teams)
+  teams_all <- unique(data$home_team)
+  team_home <- match(data$home_team, teams_all)
+  team_away <- match(data$away_team, teams_all)
 
   if (is.null(sims$diff_y_prev) & is.null(sims$y_prev)){
     stop("There is not any test set!
@@ -97,19 +123,19 @@ foot_round_robin <- function(data, object, team_sel){
     team2_prev <- c(team2_prev, team1_prev)
   }
 
-  if (missing(team_sel)){
-    team_sel <- teams[unique(team1_prev)]
+  if (is.null(teams)){
+    teams <- teams_all[unique(team1_prev)]
   }
-  team_index <- match(team_sel, teams)
+  team_index <- match(teams, teams_all)
 
 
   if (is.na(sum(team_index))){
-    warning(paste(team_sel[is.na(team_index)],
+    warning(paste(teams[is.na(team_index)],
     "is not in the test set. Pleasy provide a valid team name. "))
     team_index <- team_index[!is.na(team_index)]
   }
 
-  team_names <- teams[team_index]
+  team_names <- teams_all[team_index]
   nteams<- length(unique(team_home))
   nteams_new <- length(team_index)
   M <-dim(sims$diff_y_rep)[1]
@@ -180,29 +206,30 @@ foot_round_robin <- function(data, object, team_sel){
    data_ex <- expand.grid(Home=x_ex, Away=y_ex)
    data_ex$prob=as.double(counts_mix[1:nteams, 1:nteams][team_index, team_index])
 
-   p <- ggplot(data_ex, aes(Home, Away, z= prob)) +
-    geom_tile(aes(fill = prob)) +
-    theme_bw() +
-    labs(x_ex, xaxis_text( size = rel(1.2)))+
-    labs(y_ex, yaxis_text( size = rel(1.2)))+
-    scale_fill_gradient(low="white", high="red")+
-    scale_x_discrete( limits= team_names  ) +
-    scale_y_discrete( limits= team_names  ) +
-    theme(axis.text.x = element_text(angle = 90, hjust = 1))+
-    geom_text(aes(label=as.vector(punt[team_index, team_index])), size =2.1)+
-    geom_rect(aes(xmin =as.vector(x1_x2),
-                  xmax = as.vector(x2_x1),
-                  ymin =as.vector(x1_x2),
-                  ymax =as.vector(x2_x1)),
-                  fill = "black", color = "black",
-                  size = 1)+
-    ggtitle("Home win posterior probabilities")
+   p <- ggplot(data_ex, aes(Home, Away, z = prob)) +
+     geom_tile(aes(fill = prob)) +
+     theme_bw() +
+     labs(x = x_ex, xaxis_text(size = rel(1.2))) +
+     labs(y = y_ex, yaxis_text(size = rel(1.2))) +
+     scale_fill_gradient(low = "white", high = "red3", name = "Prob") +  # Change legend title here
+     scale_x_discrete(limits = team_names) +
+     scale_y_discrete(limits = team_names) +
+     theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
+     geom_text(aes(label = as.vector(punt[team_index, team_index])), size = 4.1) +
+     geom_rect(aes(xmin = as.vector(x1_x2),
+                   xmax = as.vector(x2_x1),
+                   ymin = as.vector(x1_x2),
+                   ymax = as.vector(x2_x1)),
+               fill = "black", color = "black",
+               size = 1) +
+     ggtitle("Home win posterior probabilities")
+
    if (sum(data_ex$prob)==0){
-      tbl <- cbind(team_sel[data_ex$Home], team_sel[data_ex$Away], as.vector(punt[team_index, team_index]))
+      tbl <- cbind(teams[data_ex$Home], teams[data_ex$Away], as.vector(punt[team_index, team_index]))
       colnames(tbl) <- c("Home", "Away", "Observed")
       tbl <- dplyr::as_tibble(tbl) %>% dplyr::filter(Home!=Away)
       }else{
-      tbl <- cbind(team_sel[data_ex$Home], team_sel[data_ex$Away], round(data_ex$prob,3),
+      tbl <- cbind(teams[data_ex$Home], teams[data_ex$Away], round(data_ex$prob,3),
                    as.vector(punt[team_index, team_index]))
       colnames(tbl) <- c("Home", "Away", "Home_prob", "Observed")
       tbl <- dplyr::as_tibble(tbl) %>% dplyr::filter(Home!=Away & Home_prob!=0 )
